.. Boss documentation master file, created by
   sphinx-quickstart on Tue May 22 19:04:27 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Boss Development Tools
======================

The Boss project provides 'Baseline Open Source Software' templates and
development tools.  It has similarities to Paste Script with regards to
templating, but far easier to extend.  Though Boss is written in Python, it is
not limited to any particular language. Boss is very beta... any feedback is
welcome and appreciated.

.. image:: https://secure.travis-ci.org/datafolklabs/boss.png
  :target: http://travis-ci.org/#!/datafolklabs/boss

Features:

  * Supports multiple local, and remote (git) template sources
  * Templates can easily be created and customized to the developers needs
  * Support for remote files within templates (i.e. github/gitignore files)

Other sites that might be helpful.

  * RTFD: http://boss.readthedocs.org/en/latest/
  * CODE: https://github.com/datafolklabs/boss/
  * PYPI: http://pypi.python.org/pypi/boss
  *   CI: http://travis-ci.org/#!/datafolklabs/boss


Official templates are available from:

 * http://github.com/datafolklabs/boss-templates


Contents:

.. toctree::
   :maxdepth: 1

   changelog
   license

.. toctree::
   :maxdepth: 2

   dev

.. toctree::
   :maxdepth: 2

   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

